tsseg.algorithms.ruptures package
=================================

Lightweight subset of ruptures v1.1.8 used by BinSeg, BottomUp, DynP, KCPD, PELT,
Window. Contains base classes, cost functions, utilities and detection algorithms.
Not a detector itself.

**Implementation:** Vendored from `ruptures <https://github.com/deepcharles/ruptures>`_.
BSD 2-Clause.

Module contents
---------------

.. automodule:: tsseg.algorithms.ruptures
   :members:
   :show-inheritance:
   :undoc-members:
